==========
Constraint
==========


The Constraint commands define constraints between regions of the model.

Create constraints
------------------

.. autoclass:: abaqus.Constraint.ConstraintModel.ConstraintModel
    :noindex:

    .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
